summaryrefslogtreecommitdiffstats
path: root/tdehtml/rendering
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2023-11-13 20:33:00 +0900
committerMichele Calgaro <michele.calgaro@yahoo.it>2023-11-15 23:44:25 +0900
commitc8ece3630d4d21acaf1749fc2cf660a0463070c3 (patch)
treebae3d3c70886ceeffd914cac031dfeab532a607a /tdehtml/rendering
parent419c185be746df8bba59fe5de991b4a2b3977897 (diff)
downloadtdelibs-c8ece3630d4d21acaf1749fc2cf660a0463070c3.tar.gz
tdelibs-c8ece3630d4d21acaf1749fc2cf660a0463070c3.zip
Replace Qt with TQt
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'tdehtml/rendering')
-rw-r--r--tdehtml/rendering/render_block.cpp4
-rw-r--r--tdehtml/rendering/render_box.cpp4
-rw-r--r--tdehtml/rendering/render_form.cpp12
-rw-r--r--tdehtml/rendering/render_form.h2
-rw-r--r--tdehtml/rendering/render_frames.cpp14
-rw-r--r--tdehtml/rendering/render_frames.h4
-rw-r--r--tdehtml/rendering/render_generated.cpp4
-rw-r--r--tdehtml/rendering/render_image.cpp10
-rw-r--r--tdehtml/rendering/render_inline.cpp2
-rw-r--r--tdehtml/rendering/render_layer.cpp14
-rw-r--r--tdehtml/rendering/render_layer.h2
-rw-r--r--tdehtml/rendering/render_list.cpp22
-rw-r--r--tdehtml/rendering/render_object.cpp18
-rw-r--r--tdehtml/rendering/render_replaced.cpp12
-rw-r--r--tdehtml/rendering/render_style.h2
-rw-r--r--tdehtml/rendering/render_table.cpp4
-rw-r--r--tdehtml/rendering/render_text.cpp2
17 files changed, 66 insertions, 66 deletions
diff --git a/tdehtml/rendering/render_block.cpp b/tdehtml/rendering/render_block.cpp
index 053e51b95..414947e1e 100644
--- a/tdehtml/rendering/render_block.cpp
+++ b/tdehtml/rendering/render_block.cpp
@@ -695,9 +695,9 @@ void RenderBlock::layoutBlock(bool relayoutChildren)
if (scrollsOverflow() && m_layer) {
// For overflow:scroll blocks, ensure we have both scrollbars in place always.
if (style()->overflowX() == OSCROLL)
- m_layer->showScrollbar( Qt::Horizontal, true );
+ m_layer->showScrollbar( TQt::Horizontal, true );
if (style()->overflowY() == OSCROLL)
- m_layer->showScrollbar( Qt::Vertical, true );
+ m_layer->showScrollbar( TQt::Vertical, true );
}
setContainsPageBreak(false);
diff --git a/tdehtml/rendering/render_box.cpp b/tdehtml/rendering/render_box.cpp
index d804094ef..7dc07090d 100644
--- a/tdehtml/rendering/render_box.cpp
+++ b/tdehtml/rendering/render_box.cpp
@@ -644,8 +644,8 @@ void RenderBox::paintBackgroundExtended(TQPainter *p, const TQColor &c, const Ba
void RenderBox::outlineBox(TQPainter *p, int _tx, int _ty, const char *color)
{
- p->setPen(TQPen(TQColor(color), 1, Qt::DotLine));
- p->setBrush( Qt::NoBrush );
+ p->setPen(TQPen(TQColor(color), 1, TQt::DotLine));
+ p->setBrush( TQt::NoBrush );
p->drawRect(_tx, _ty, m_width, m_height);
}
diff --git a/tdehtml/rendering/render_form.cpp b/tdehtml/rendering/render_form.cpp
index 33f045553..f28706bd3 100644
--- a/tdehtml/rendering/render_form.cpp
+++ b/tdehtml/rendering/render_form.cpp
@@ -99,25 +99,25 @@ void RenderFormElement::layout()
setNeedsLayout(false);
}
-Qt::AlignmentFlags RenderFormElement::textAlignment() const
+TQt::AlignmentFlags RenderFormElement::textAlignment() const
{
switch (style()->textAlign()) {
case LEFT:
case TDEHTML_LEFT:
- return Qt::AlignLeft;
+ return TQt::AlignLeft;
case RIGHT:
case TDEHTML_RIGHT:
- return Qt::AlignRight;
+ return TQt::AlignRight;
case CENTER:
case TDEHTML_CENTER:
- return Qt::AlignHCenter;
+ return TQt::AlignHCenter;
case JUSTIFY:
// Just fall into the auto code for justify.
case TAAUTO:
- return style()->direction() == RTL ? Qt::AlignRight : Qt::AlignLeft;
+ return style()->direction() == RTL ? TQt::AlignRight : TQt::AlignLeft;
}
assert(false); // Should never be reached.
- return Qt::AlignLeft;
+ return TQt::AlignLeft;
}
// -------------------------------------------------------------------------
diff --git a/tdehtml/rendering/render_form.h b/tdehtml/rendering/render_form.h
index 8fa2099f8..9c46346a7 100644
--- a/tdehtml/rendering/render_form.h
+++ b/tdehtml/rendering/render_form.h
@@ -95,7 +95,7 @@ public:
protected:
virtual bool isRenderButton() const { return false; }
virtual bool isEditable() const { return false; }
- Qt::AlignmentFlags textAlignment() const;
+ TQt::AlignmentFlags textAlignment() const;
TQPoint m_mousePos;
int m_state;
diff --git a/tdehtml/rendering/render_frames.cpp b/tdehtml/rendering/render_frames.cpp
index f92d0b281..70bb4fc17 100644
--- a/tdehtml/rendering/render_frames.cpp
+++ b/tdehtml/rendering/render_frames.cpp
@@ -66,7 +66,7 @@ RenderFrameSet::RenderFrameSet( HTMLFrameSetElementImpl *frameSet)
m_resizing = m_clientresizing= false;
- m_cursor = Qt::ArrowCursor;
+ m_cursor = TQt::ArrowCursor;
m_hSplit = -1;
m_vSplit = -1;
@@ -498,13 +498,13 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
}
- m_cursor = Qt::ArrowCursor;
+ m_cursor = TQt::ArrowCursor;
if(m_hSplit != -1 && m_vSplit != -1)
- m_cursor = Qt::SizeAllCursor;
+ m_cursor = TQt::SizeAllCursor;
else if( m_vSplit != -1 )
- m_cursor = Qt::SizeHorCursor;
+ m_cursor = TQt::SizeHorCursor;
else if( m_hSplit != -1 )
- m_cursor = Qt::SizeVerCursor;
+ m_cursor = TQt::SizeVerCursor;
if(!m_resizing && evt->id() == EventImpl::MOUSEDOWN_EVENT)
{
@@ -548,8 +548,8 @@ bool RenderFrameSet::userResize( MouseEventImpl *evt )
TDEHTMLView *view = canvas()->view();
if ((m_resizing || evt->id() == EventImpl::MOUSEUP_EVENT) && view) {
TQPainter paint( view );
- paint.setPen( Qt::gray );
- paint.setBrush( Qt::gray );
+ paint.setPen( TQt::gray );
+ paint.setBrush( TQt::gray );
paint.setRasterOp( TQt::XorROP );
TQRect r(xPos(), yPos(), width(), height());
const int rBord = 3;
diff --git a/tdehtml/rendering/render_frames.h b/tdehtml/rendering/render_frames.h
index 578dabaab..a6e0640f3 100644
--- a/tdehtml/rendering/render_frames.h
+++ b/tdehtml/rendering/render_frames.h
@@ -61,7 +61,7 @@ public:
bool canResize( int _x, int _y);
void setResizing(bool e);
- Qt::CursorShape cursorShape() const { return m_cursor; }
+ TQt::CursorShape cursorShape() const { return m_cursor; }
bool nodeAtPoint(NodeInfo& info, int x, int y, int tx, int ty, HitTestAction hitTestAction, bool inside);
@@ -73,7 +73,7 @@ public:
#endif
private:
- Qt::CursorShape m_cursor;
+ TQt::CursorShape m_cursor;
int m_oldpos;
int m_gridLen[2];
int* m_gridDelta[2];
diff --git a/tdehtml/rendering/render_generated.cpp b/tdehtml/rendering/render_generated.cpp
index 3f8d6e8f0..cf945145f 100644
--- a/tdehtml/rendering/render_generated.cpp
+++ b/tdehtml/rendering/render_generated.cpp
@@ -358,7 +358,7 @@ void RenderGlyph::paint(PaintInfo& paintInfo, int _tx, int _ty)
p->drawEllipse( marker );
return;
case LCIRCLE:
- p->setBrush( Qt::NoBrush );
+ p->setBrush( TQt::NoBrush );
p->drawEllipse( marker );
return;
case LSQUARE:
@@ -366,7 +366,7 @@ void RenderGlyph::paint(PaintInfo& paintInfo, int _tx, int _ty)
p->drawRect( marker );
return;
case LBOX:
- p->setBrush( Qt::NoBrush );
+ p->setBrush( TQt::NoBrush );
p->drawRect( marker );
return;
case LDIAMOND: {
diff --git a/tdehtml/rendering/render_image.cpp b/tdehtml/rendering/render_image.cpp
index ad8f18bb3..bfe5781ac 100644
--- a/tdehtml/rendering/render_image.cpp
+++ b/tdehtml/rendering/render_image.cpp
@@ -243,10 +243,10 @@ void RenderImage::paint(PaintInfo& paintInfo, int _tx, int _ty)
if (bUnfinishedImageFrame && paintInfo.phase == PaintActionForeground && cWidth > 2 && cHeight > 2 && !complete()) {
static TQPixmap *loadingIcon;
TQColor bg = tdehtml::retrieveBackgroundColor(this);
- TQColor fg = tdehtml::hasSufficientContrast(Qt::gray, bg) ? Qt::gray :
- (hasSufficientContrast(Qt::white, bg) ? Qt::white : Qt::black);
+ TQColor fg = tdehtml::hasSufficientContrast(TQt::gray, bg) ? TQt::gray :
+ (hasSufficientContrast(TQt::white, bg) ? TQt::white : TQt::black);
paintInfo.p->setPen(TQPen(fg, 1));
- paintInfo.p->setBrush( Qt::NoBrush );
+ paintInfo.p->setBrush( TQt::NoBrush );
paintInfo.p->drawRect(_tx, _ty, m_width, m_height);
if (!(m_width <= 5 || m_height <= 5)) {
if (!loadingIcon) {
@@ -289,7 +289,7 @@ void RenderImage::paint(PaintInfo& paintInfo, int _tx, int _ty)
}
else if (i && !i->isTransparent())
{
- paintInfo.p->setPen( Qt::black ); // used for bitmaps
+ paintInfo.p->setPen( TQt::black ); // used for bitmaps
const TQPixmap& pix = i->pixmap();
if ( (cWidth != intrinsicWidth() || cHeight != intrinsicHeight()) &&
pix.width() > 0 && pix.height() > 0 && i->valid_rect().isValid())
@@ -371,7 +371,7 @@ void RenderImage::paint(PaintInfo& paintInfo, int _tx, int _ty)
paintInfo.p->setBrushOrigin(_tx, _ty - paintInfo.r.y());
paintInfo.p->fillRect(_tx, _ty, width(), height(),
TQBrush(style()->palette().active().highlight(),
- Qt::Dense4Pattern));
+ TQt::Dense4Pattern));
}
}
}
diff --git a/tdehtml/rendering/render_inline.cpp b/tdehtml/rendering/render_inline.cpp
index 15bc1b0df..5439a5310 100644
--- a/tdehtml/rendering/render_inline.cpp
+++ b/tdehtml/rendering/render_inline.cpp
@@ -678,7 +678,7 @@ static void paintOutlineSegment(RenderObject *o, TQPainter *p, int tx, int ty,
}
// kdDebug(6040) << "segment(" << x1 << "," << y1 << ") - (" << x2 << "," << y2 << ")" << endl;
-/* p->setPen(Qt::gray);
+/* p->setPen(TQt::gray);
p->drawLine(x1,y1,x2,y2);*/
switch (curBS) {
case RenderObject::BSLeft:
diff --git a/tdehtml/rendering/render_layer.cpp b/tdehtml/rendering/render_layer.cpp
index 2b6bbf027..24e00ebe8 100644
--- a/tdehtml/rendering/render_layer.cpp
+++ b/tdehtml/rendering/render_layer.cpp
@@ -604,9 +604,9 @@ void RenderLayer::updateScrollPositionFromScrollbars()
}
void
-RenderLayer::showScrollbar(Qt::Orientation o, bool show)
+RenderLayer::showScrollbar(TQt::Orientation o, bool show)
{
- TQScrollBar *sb = (o == Qt::Horizontal) ? m_hBar : m_vBar;
+ TQScrollBar *sb = (o == TQt::Horizontal) ? m_hBar : m_vBar;
if (show && !sb) {
TQScrollView* scrollView = m_object->document()->view();
@@ -623,7 +623,7 @@ RenderLayer::showScrollbar(Qt::Orientation o, bool show)
sb = 0;
}
- if (o == Qt::Horizontal)
+ if (o == TQt::Horizontal)
m_hBar = sb;
else
m_vBar = sb;
@@ -749,12 +749,12 @@ void RenderLayer::checkScrollbarsAfterLayout()
|| (hasOvf && m_object->style()->overflowY() == OAUTO && haveVerticalBar != needVerticalBar);
if (scrollbarsChanged) {
if (m_object->style()->overflowX() == OAUTO) {
- showScrollbar(Qt::Horizontal, needHorizontalBar);
+ showScrollbar(TQt::Horizontal, needHorizontalBar);
if (m_hBar)
m_hBar->setEnabled(true);
}
if (m_object->style()->overflowY() == OAUTO) {
- showScrollbar(Qt::Vertical, needVerticalBar);
+ showScrollbar(TQt::Vertical, needVerticalBar);
if (m_vBar)
m_vBar->setEnabled(true);
}
@@ -956,8 +956,8 @@ void RenderLayer::paintLayer(RenderLayer* rootLayer, TQPainter *p,
int ax=0;
int ay=0;
renderer()->absolutePosition( ax, ay );
- p->setPen(TQPen(TQColor("yellow"), 1, Qt::DotLine));
- p->setBrush( Qt::NoBrush );
+ p->setPen(TQPen(TQColor("yellow"), 1, TQt::DotLine));
+ p->setBrush( TQt::NoBrush );
p->drawRect(ax, ay, width(), height());
}
#endif
diff --git a/tdehtml/rendering/render_layer.h b/tdehtml/rendering/render_layer.h
index a71549cc5..9c73eb0bb 100644
--- a/tdehtml/rendering/render_layer.h
+++ b/tdehtml/rendering/render_layer.h
@@ -193,7 +193,7 @@ public:
void scrollToOffset(int x, int y, bool updateScrollbars = true, bool repaint = true);
void scrollToXOffset(int x) { scrollToOffset(x, m_scrollY); }
void scrollToYOffset(int y) { scrollToOffset(m_scrollX, y); }
- void showScrollbar(Qt::Orientation, bool);
+ void showScrollbar(TQt::Orientation, bool);
TQScrollBar* horizontalScrollbar() { return m_hBar; }
TQScrollBar* verticalScrollbar() { return m_vBar; }
int verticalScrollbarWidth();
diff --git a/tdehtml/rendering/render_list.cpp b/tdehtml/rendering/render_list.cpp
index cc9ba4e5b..17caa26ae 100644
--- a/tdehtml/rendering/render_list.cpp
+++ b/tdehtml/rendering/render_list.cpp
@@ -299,7 +299,7 @@ void RenderListMarker::paint(PaintInfo& paintInfo, int _tx, int _ty)
}
#ifdef BOX_DEBUG
- p->setPen( Qt::red );
+ p->setPen( TQt::red );
p->drawRect( _tx + xoff, _ty + yoff, offset, offset );
#endif
@@ -312,7 +312,7 @@ void RenderListMarker::paint(PaintInfo& paintInfo, int _tx, int _ty)
p->drawEllipse( _tx + xoff, _ty + (3 * yoff)/2, (offset>>1)+1, (offset>>1)+1 );
return;
case LCIRCLE:
- p->setBrush( Qt::NoBrush );
+ p->setBrush( TQt::NoBrush );
p->drawEllipse( _tx + xoff, _ty + (3 * yoff)/2, (offset>>1)+1, (offset>>1)+1 );
return;
case LSQUARE:
@@ -320,7 +320,7 @@ void RenderListMarker::paint(PaintInfo& paintInfo, int _tx, int _ty)
p->drawRect( _tx + xoff, _ty + (3 * yoff)/2, (offset>>1)+1, (offset>>1)+1 );
return;
case LBOX:
- p->setBrush( Qt::NoBrush );
+ p->setBrush( TQt::NoBrush );
p->drawRect( _tx + xoff, _ty + (3 * yoff)/2, (offset>>1)+1, (offset>>1)+1 );
return;
case LDIAMOND: {
@@ -342,25 +342,25 @@ void RenderListMarker::paint(PaintInfo& paintInfo, int _tx, int _ty)
if (!m_item.isEmpty()) {
if(listPositionInside()) {
if( style()->direction() == LTR) {
- p->drawText(_tx, _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, m_item);
- p->drawText(_tx + fm.width(m_item), _ty, 0, 0, Qt::AlignLeft|TQt::DontClip,
+ p->drawText(_tx, _ty, 0, 0, TQt::AlignLeft|TQt::DontClip, m_item);
+ p->drawText(_tx + fm.width(m_item), _ty, 0, 0, TQt::AlignLeft|TQt::DontClip,
TQString::fromLatin1(". "));
}
else {
const TQString& punct(TQString::fromLatin1(" ."));
- p->drawText(_tx, _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, punct);
- p->drawText(_tx + fm.width(punct), _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, m_item);
+ p->drawText(_tx, _ty, 0, 0, TQt::AlignLeft|TQt::DontClip, punct);
+ p->drawText(_tx + fm.width(punct), _ty, 0, 0, TQt::AlignLeft|TQt::DontClip, m_item);
}
} else {
if (style()->direction() == LTR) {
const TQString& punct(TQString::fromLatin1(". "));
- p->drawText(_tx-offset/2, _ty, 0, 0, Qt::AlignRight|TQt::DontClip, punct);
- p->drawText(_tx-offset/2-fm.width(punct), _ty, 0, 0, Qt::AlignRight|TQt::DontClip, m_item);
+ p->drawText(_tx-offset/2, _ty, 0, 0, TQt::AlignRight|TQt::DontClip, punct);
+ p->drawText(_tx-offset/2-fm.width(punct), _ty, 0, 0, TQt::AlignRight|TQt::DontClip, m_item);
}
else {
const TQString& punct(TQString::fromLatin1(" ."));
- p->drawText(_tx+offset/2, _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, punct);
- p->drawText(_tx+offset/2+fm.width(punct), _ty, 0, 0, Qt::AlignLeft|TQt::DontClip, m_item);
+ p->drawText(_tx+offset/2, _ty, 0, 0, TQt::AlignLeft|TQt::DontClip, punct);
+ p->drawText(_tx+offset/2+fm.width(punct), _ty, 0, 0, TQt::AlignLeft|TQt::DontClip, m_item);
}
}
}
diff --git a/tdehtml/rendering/render_object.cpp b/tdehtml/rendering/render_object.cpp
index eacbb4d16..b1a9bdffc 100644
--- a/tdehtml/rendering/render_object.cpp
+++ b/tdehtml/rendering/render_object.cpp
@@ -722,7 +722,7 @@ static void calc3DColor(TQColor &color, bool darken)
int g = gb - (f0 * gb / 100);
int b = bb - (f0 * bb / 100);
if ((r == rb) && (g == gb) && (b == bb))
- color = (color == Qt::black) ? DARK_GRAY : Qt::black;
+ color = (color == TQt::black) ? DARK_GRAY : TQt::black;
else
color.setRgb(r, g, b);
} else {
@@ -730,7 +730,7 @@ static void calc3DColor(TQColor &color, bool darken)
int g = kMin(gb + (f1 * (MAX_COLOR - gb) / 100), 255);
int b = kMin(bb + (f1 * (MAX_COLOR - bb) / 100), 255);
if ((r == rb) && (g == gb) && (b == bb))
- color = (color == Qt::white) ? LIGHT_GRAY : Qt::white;
+ color = (color == TQt::white) ? LIGHT_GRAY : TQt::white;
else
color.setRgb(r, g, b);
}
@@ -749,12 +749,12 @@ void RenderObject::drawBorder(TQPainter *p, int x1, int y1, int x2, int y2,
if(invalidisInvert)
{
p->setRasterOp(TQt::XorROP);
- c = Qt::white;
+ c = TQt::white;
}
else {
if(style == INSET || style == OUTSET || style == RIDGE || style ==
GROOVE)
- c = Qt::white;
+ c = TQt::white;
else
c = textcolor;
}
@@ -773,7 +773,7 @@ void RenderObject::drawBorder(TQPainter *p, int x1, int y1, int x2, int y2,
case DOTTED:
if ( width == 1 ) {
// workaround Qt brokenness
- p->setPen(TQPen(c, width, Qt::SolidLine));
+ p->setPen(TQPen(c, width, TQt::SolidLine));
switch(s) {
case BSBottom:
case BSTop:
@@ -788,11 +788,11 @@ void RenderObject::drawBorder(TQPainter *p, int x1, int y1, int x2, int y2,
break;
}
- p->setPen(TQPen(c, width, Qt::DotLine));
+ p->setPen(TQPen(c, width, TQt::DotLine));
/* nobreak; */
case DASHED:
if(style == DASHED)
- p->setPen(TQPen(c, width == 1 ? 0 : width, width == 1 ? Qt::DotLine : Qt::DashLine));
+ p->setPen(TQPen(c, width == 1 ? 0 : width, width == 1 ? TQt::DotLine : TQt::DashLine));
if (width > 0)
switch(s) {
@@ -813,7 +813,7 @@ void RenderObject::drawBorder(TQPainter *p, int x1, int y1, int x2, int y2,
if (adjbw1 == 0 && adjbw2 == 0)
{
- p->setPen(Qt::NoPen);
+ p->setPen(TQt::NoPen);
p->setBrush(c);
switch(s)
{
@@ -921,7 +921,7 @@ void RenderObject::drawBorder(TQPainter *p, int x1, int y1, int x2, int y2,
(style == INSET && ( s == BSTop || s == BSLeft ) ) );
/* nobreak; */
case SOLID:
- p->setPen(Qt::NoPen);
+ p->setPen(TQt::NoPen);
p->setBrush(c);
Q_ASSERT(x2>=x1);
Q_ASSERT(y2>=y1);
diff --git a/tdehtml/rendering/render_style.h b/tdehtml/rendering/render_style.h
index 28b6b999d..90aef33df 100644
--- a/tdehtml/rendering/render_style.h
+++ b/tdehtml/rendering/render_style.h
@@ -1450,7 +1450,7 @@ public:
static short initialBorderHorizontalSpacing() { return 0; }
static short initialBorderVerticalSpacing() { return 0; }
static ECursor initialCursor() { return CURSOR_AUTO; }
- static TQColor initialColor() { return Qt::black; }
+ static TQColor initialColor() { return TQt::black; }
static CachedImage* initialBackgroundImage() { return 0; }
static CachedImage* initialListStyleImage() { return 0; }
static unsigned short initialBorderWidth() { return 3; }
diff --git a/tdehtml/rendering/render_table.cpp b/tdehtml/rendering/render_table.cpp
index ab0573048..bd4002a37 100644
--- a/tdehtml/rendering/render_table.cpp
+++ b/tdehtml/rendering/render_table.cpp
@@ -2699,8 +2699,8 @@ int RenderTableCell::borderBottom() const
static void outlineBox(TQPainter *p, int _tx, int _ty, int w, int h)
{
- p->setPen(TQPen(TQColor("yellow"), 3, Qt::DotLine));
- p->setBrush( Qt::NoBrush );
+ p->setPen(TQPen(TQColor("yellow"), 3, TQt::DotLine));
+ p->setBrush( TQt::NoBrush );
p->drawRect(_tx, _ty, w, h );
}
#endif
diff --git a/tdehtml/rendering/render_text.cpp b/tdehtml/rendering/render_text.cpp
index 5361027d1..c2bf27af5 100644
--- a/tdehtml/rendering/render_text.cpp
+++ b/tdehtml/rendering/render_text.cpp
@@ -398,7 +398,7 @@ void InlineTextBox::paintShadow(TQPainter *pt, const Font *f, int _tx, int _ty,
}
}
- pt->drawImage(x-thickness, y-thickness, res, 0, 0, -1, -1, Qt::DiffuseAlphaDither | Qt::ColorOnly | Qt::PreferDither);
+ pt->drawImage(x-thickness, y-thickness, res, 0, 0, -1, -1, TQt::DiffuseAlphaDither | TQt::ColorOnly | TQt::PreferDither);
}
// Paint next shadow effect
if (shadow->next) paintShadow(pt, f, _tx, _ty, shadow->next);
diff --git a/tdehtml/rendering/render_replaced.cpp b/tdehtml/rendering/render_replaced.cpp
index 925f800fd..09931c3de 100644
--- a/tdehtml/rendering/render_replaced.cpp
+++ b/tdehtml/rendering/render_replaced.cpp
@@ -316,12 +316,12 @@ void RenderWidget::updateFromElement()
if (v > 128)
// dark bg, light fg - need a darker disabled fg
disfg = disfg.dark(lowlightVal);
- else if (disfg != Qt::black)
+ else if (disfg != TQt::black)
// light bg, dark fg - need a lighter disabled fg - but only if !black
disfg = disfg.light(highlightVal);
else
// black fg - use darkgray disabled fg
- disfg = Qt::darkGray;
+ disfg = TQt::darkGray;
pal.setColor(TQPalette::Disabled,TQColorGroup::Foreground,disfg);
}
@@ -784,13 +784,13 @@ bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
}
switch (me.button()) {
case 0:
- button = Qt::LeftButton;
+ button = TQt::LeftButton;
break;
case 1:
- button = Qt::MidButton;
+ button = TQt::MidButton;
break;
case 2:
- button = Qt::RightButton;
+ button = TQt::RightButton;
break;
default:
break;
@@ -847,7 +847,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
// DOM: Down Press | Press | Up
// Qt: (nothing) Press | Release(autorepeat) + Press(autorepeat) | Release
//
// Qt::KeyPress is sent for DOM keypress and not DOM keydown to allow
// sites to block a key with onkeypress, #99749
TQKeyEvent* const ke = domKeyEv.qKeyEvent();
@@ -847,7 +847,7 @@ bool RenderWidget::handleEvent(const DOM::EventImpl& ev)
// Qt: (nothing) Press | Release(autorepeat) + Press(autorepeat) | Release
//
- // Qt::KeyPress is sent for DOM keypress and not DOM keydown to allow
+ // TQt::KeyPress is sent for DOM keypress and not DOM keydown to allow
// sites to block a key with onkeypress, #99749
TQKeyEvent* const ke = domKeyEv.qKeyEvent();